                         |      |    |    |\    |     /    |    |     |\   \    /
	         	 |      |    |    | \   |    /     |    |     | \   \  /
                         |  /\  |    |    |  \  |   / \    |____|__   | /    \/     
		         | /  \ |    |    |   \ |  |   \        |     |       |
		         |/    \|    |    |    \|  \___/        |     |       |


WIN64INSTALLER (OR) WIN64PYINSTALLER IS AN SUBMODULE OF THE MAIN MODULE WIN64PY WHICH IS EXPECTED TO BE RELEASED SOON.

WIN64INSTALLER FETCHES THE FILE FROM THE PROVIDED URL AND DOWNLOADES IT USING A BIT OF POWERSHELL MAGIC.
THIS MODULE WILL BE MAINTAINED UNTILL THE MAIN MODULE WIN64PY IS RELEASED. AFTER THAT THE MODULE BECOMES A PART OF
WIN64PY AND WOULD BE DELETED SO THAT THE USERS HAVE THE UPDATED VERSION IN WIN64PY

THANK YOU FOR USING THIS MODULE!!	